## PLOTS THE DIFFERENT PREFERENCE FUNCTIONS

# DEFINE THE FUNCTIONS

# Parameters:
# f  female trait
# m  male trait
# c  strength of assortment (1/2 random)
# sA \sigma_A, width of the choice function

Doebeli <- function(f, m, c, sA){
	if (c>1/2){
		exp(-1/2*((2*c-1)^2/(sA))^2 * (f-m)^2)
	}else{if(c==1/2){
		rep(1, length(m))
	}else{
		exp(-1/2*((2*c-1)^2/(sA))^2 * (1-abs(f-m))^2)
	}}
}

Gavrilets <- function(f, m, c, sA){
	if (c>1/2){
		exp(-1/2*((2*c-1)/(sA))^2 * (f-m)^2)
	}else{if(c==1/2){
		rep(1, length(m))
	}else{
		exp(-1/2*((2*c-1)/(sA))^2 * (f-(1-m))^2)
	}}
}

Myfunc <- function(f, m, c, sA){
	if (c>1/2){
		1 - (2*c-1)^2 * (1 - exp(-(f-m)^2 / (2*sA^2)))
	}else{if(c==1/2){
		rep(1, length(m))
	}else{
		1 - (2*c-1)^2 * (exp(-(f-m)^2 / (2*sA^2)))
	}}
}

# PLOTTING

# Colors
nc <- 5;	# Nbr of different c values
cols <- hsv((1:nc)/nc)	# Color rainbow
ltys <- c(1, 2, 1, 2, 1);
lwds <- c(2, 2, 3, 2, 2);
cols <- gray(c(rep(0.2,2), 0, rep(0.6, 2)));

# Function for plotting
# Parameters:
# pref   the name of the preference function
# f      the focal female trait
# prms   sA parameter
# cols   list of colors
# dev    output device
# name   name of the file for output
# legend whether a legend should be drawn
plotpref <- function(pref, f, prms, cols, dev='X11', name='', legend=0){
	if(dev=='pdf'){pdf(width=4,height=3,file=name)}
	par(mar=c(4.5,4,0.5,0)+0.2)
	n <- length(cols); clist <- seq(0,1,length.out=n);
	dx <- 10*prms$sA;
	plot(0, xlim=c(1/2-dx, 1/2+dx), ylim=c(0,1), xlab='Male trait', ylab='Female preference', col='white', cex.lab=1.4, cex.axis=1.2)
	xlist <- seq(1/2-dx,1/2+ dx, length.out=101)
	for (i in 1:n){
		lines(xlist, get(pref)(f, xlist, clist[i], prms$sA), col=cols[i], lwd=lwds[i], lty=ltys[i])
	}
	lines(rep(f,2), c(0,1), col='black', lty=2)
	if(legend==1){
		for (i in 1:n){
			lines(c(-1, -0.7), rep(0.3+0.6*(i)/n,2), col=cols[i], lwd=lwds[i], lty=ltys[i])
		}		
		text(rep(-0.7,n), 0.3+0.6*(1:n)/n, paste(" ",as.character(round(clist,2)),sep=''), col=cols, pos=4)
	}
	if(dev=='pdf')dev.off()
}

## PLOTTING!
thef <- 0.4;	# Focal female trait
thesA <- 0.15;	# \sigma_A
plotpref('Doebeli', thef, prms=list(sA=thesA), cols, dev='pdf', name='figures/Doebeli.pdf')
plotpref('Gavrilets', thef, prms=list(sA=thesA), cols, dev='pdf', name='figures/Gravrilets.pdf', legend=1)
plotpref('Myfunc', thef, prms=list(sA=thesA), cols, dev='pdf', name='figures/Myfunc.pdf')
