# data: Thibert-Plante and Hendry, 2011, JEB 24(10):2186--2196.

# Clear the memory
rm(list=ls())
# Close all figure windows
for(i in dev.list())dev.off()

## PARAMETERS WHICH CAN BE CHANGED
#  Changing these arbitrary thresdhold values change the pies charts (it's worth playing with them..,)

# Minimum value of "adapt" to declare the pop adapted (= remove zone 3)
adaptthr <- 0.7;

# Maximum value of "hybrids3" to declare incipient sympatric speciation ( = limit between zones 1 and 2)
#		Max stringency = 0
#		Min stringency = 1
maxhybrid <- 0.4;	# This is an arbitrary limit. TPH used 0.6. I prefer using a bit more stringent criterion.
# There is another point at 0 anyway, for the limit between zones 0 and 1

## INITIALIZATIONS

# LOAD PACKAGES
# Load the R.basic package (uncomment the two lines below to download it) for 3d plots
#source("http://www.braju.com/R/hbLite.R")
#hbLite()
library(R.basic)
# Load plotrix for the pie charts
#install.packages('plotrix')
library(plotrix)

# LOAD DATA
# Load and format
# [Xavier's code]
load("data/rep09.RData")
y<-matrix(NA,ncol=length(x[1,]),nrow=length(x[,1]))
for (i in 1:length(x[1,])) {
   y[,i]<-as.numeric(x[,i])
}
tmpColname<-colnames(x)
tmpColname[32]<-"meanPref"
colnames(y)<-tmpColname
x<-y
x<-data.frame(x)
rm(y)
# [end of Xavier's code]

# Remove data:
# Remove data where there are NAs
x <- x[!is.na(x$myVar),]
# Remove the case where c<1/2 (because weird function, does not correspond to disassortative mating, and c=0)
x <- x[x$maxPref!=0.3 & x$maxPref!=0,];
# Remove sC and sR = 1000, because correspond to virtually no selection
x <- x[x$sC!=1000 & x$sR!=1000,];

adapt<-x$popS/x$K
# Optional: remove data where adaptation is below a threshold (for instance 0.7 to remove zone 3)
ia <- adapt>adaptthr;
x <- x[ia,];
cat((1-mean(ia))*100,'% of the simulations were below the adapt thresdhold \n')
#adapt<-x$popS/x$K
#ia2 <- (adapt<0.7)

## ANALYSE DATA

# CRITERION FOR SYMPATRIC SPECIATION
# Mode of the distribution
# [Xavier's code]
bino<-rep(0,17)
for (i in 1:17){
k<-i-1
bino[i]<-(factorial(17)/(factorial(k)*factorial(17-k)) )* (0.5)^17
}
hybrids1<-((x$center1/x$popS)/sum(bino[8+1]))
hybrids2<-((x$center2/x$popS)/sum(bino[(7:9)+1]))
hybrids3<-((x$center3/x$popS)/sum(bino[(6:10)+1]))
# [end of Xavier's code]
# NOTE: This is a corrected version. The midpoint between 1 and 17 is not 8, but it is 9. 
hybrids <- hybrids3

# Index of whether sympatric speciation
# You can change the threshold (see above)
symspe <- 1*(hybrids<=maxhybrid)	# Incipient sympatric speciation ("zone 1")
totsymspe <- 1*(hybrids==0)			# Full sympatric speciation ("zone 0")

# COMPUTE THE THREE COMPOUND PARAMETERS
# Dimension 1 (CC): whether the distribution of resources is perceived as bimodal
# sCC = 1 when bimodal
concav <- function(tab){
	out <- tab$dPos^2 - 4*(tab$sR^2 - tab$sC^2); 
}
CC0 <- concav(x)
sCC0 <- 1*(CC0>0)

# Dimension 2 (SS): whether selection is globally stabilizing
# This is the condition for disruptive selection, derived under an adaptive dynamics framework
# (the derivation is not trival, the result looks simple...)
# sSS = 1 when disruptive
stabsel <- function(tab, thr=0){
	cb <- (1/4*tab$dPos^2 + (tab$sR^2 - tab$sC^2))/tab$sC^4;
}
SS <- stabsel(x)
sSS <- 1*(SS>0)

# Dimension 1 and 2 merged, because CC>0 only has a meaning when sSS>0
sCC <- sCC0 * sSS
CC <- min(CC0) + (-min(CC0) + CC0) * sSS

# Dimension 3 (PP): strengh of preference
# sPP = 0 for random mating, = 1 when some assortment
prefs <- (2*x$maxPref-1)^2/(2*x$sA^2)
sPP <- 0*(prefs==0) + 1*(prefs>0)

# ANALYSE DATA WITH THESE THREE AXES
newx <- as.data.frame(cbind(symspe, totsymspe, sCC, sSS, sPP, combined=100*sPP+10*sSS+1*sCC))
	# Mean values
xagg <- aggregate(newx, by=list(newx$combined), mean)
	# Number of simulations
xlen <- aggregate(newx, by=list(newx$combined), length)

cat('\n Aggregated results: \n')
print(as.data.frame(cbind(FreqSymSpe1=xagg$symspe, FreqSymSpe0=xagg$totsymspe, NbSymSpe1=xagg$symspe * xlen$symspe, NbSymSpe0=xagg$totsymspe * xlen$symspe, ResourcesMod=xagg$sCC, DisrupSel=xagg$sSS, SexPreference=xagg$sPP, CombinedCode=xagg$combined)))

sum(xlen$symspe)


## PLOT THE RESULT
pdf('figures/fig3A.pdf', width=4, height=3.5)

	alim <- c(-0.25,1.25);	# Plot range
	marp <- rep(0,4);	# Margins
	par('mar'=marp)

	ctheta <- 30;
	cphi <- 25;
	cr <- 2;

	gridcol <- gray(0.4)	# Color of the cube
	gridcol2 <- gray(0.8)	# Color of the cube
	# Initiate the plot
	p0 <- plot3d(x=xagg$sCC, y=xagg$sSS, z=xagg$sPP, col='white', axes=FALSE, box=FALSE, mar=marp, xlab="",ylab="",zlab="", xlim=alim, zlim=alim, ylim=alim, theta=ctheta, phi=cphi, r=cr, d=1)
	# Plot the cube
	lines3d(x=c(0,1,1,0,0), y=c(0,0,1,1,0), z=rep(0,5), col=gridcol)
	lines3d(x=c(0,1,1,0,0), y=c(0,0,1,1,0), z=rep(1,5), col=gridcol)
	lines3d(x=rep(0,2), z=c(0,1), y=rep(0,2), col=gridcol)
	lines3d(x=rep(1,2), z=c(0,1), y=rep(0,2), col=gridcol2)
	lines3d(x=rep(0,2), z=c(0,1), y=rep(1,2), col=gridcol)
	lines3d(x=rep(1,2), z=c(0,1), y=rep(1,2), col=gridcol)
	# Plot the data
	maxcex <- 2.75;

	# Annotations
	cexl <- 0.8;
	cexa <- 1;
	dl <- 0.25;
	da <- 0.75;
	fontaxis <- 1
	fontdots <- 3
	text(0.2,-0.32,"Stabilizing", cex=cexl, font=fontdots)
	text(0.35,-0.1,"Disruptive", cex=cexl, font=fontdots)
	text(0.225,-0.225,"Selection\n(Y)", cex=cexa, srt=55, font=fontaxis)

	text(-0.275,-0.27,"Unimodal", cex=cexl, font=fontdots)
	text(0.075,-0.37,"Bimodal", cex=cexl, font=fontdots)
	text(-0.08,-0.31,"Rel. resource\n Distribution\n(X)", cex=cexa, srt=-20, font=fontaxis)

	text(-0.3, 0.15, 'Assortative', cex=cexl, pos=2, font=fontdots)
	text(-0.255, -0.175, 'Random', cex=cexl, pos=2, font=fontdots)
	text(-0.3, -0.025, '(Z)\nMating', cex=cexa, srt=97.5, font=fontaxis)
	# Add pie charts showing the proportion of simulations where there are less hybrids than expected
	# get 2d coordinates of the 3d points
	to2d <- trans3d(xagg$sCC, xagg$sSS, xagg$sPP, p0);
	therad <- 0.065;	# Radius of the pie charts
	thelwd <- 10^-6;	# Line width of the pie charts

	prads <- xlen$totsymspe / max(xlen$totsymspe);

	# Colors:
	colno <- gray(0.875) # No sympatric speciation (hybrid3>maxhybrid)
	colspe <- gray(0.7) # On their way (0<hybrid3<maxhybrid)
	coltot <- gray(0) # Total sympatric speciation (hybrid3==0)

	# Plot the pie charts
	for(i in 1:6){
	if(xagg$symspe[i]>0){
		if(xagg$totsymspe[i]>0){	# If three sectors
			floating.pie(to2d$x[i], to2d$y[i], c(xagg$symspe[i]-0.99*xagg$totsymspe[i], 1-xagg$symspe[i], xagg$totsymspe[i]), col=c(colspe, colno, coltot), radius=therad/2*(1+prads[i]), lwd=thelwd, border=colno)
		}else{										# If two sectors
			floating.pie(to2d$x[i], to2d$y[i], c(xagg$symspe[i], 1-xagg$symspe[i]), col=c(colspe, colno), radius=therad/2*(1+prads[i]), lwd=thelwd, border=colno)
		}
	}else{											# If one sector (never speciation)
		floating.pie(to2d$x[i], to2d$y[i], c(1), col=c(colno), radius=therad/2*(1+prads[i]), lwd=thelwd, border=colno)
	}
}
	tcex=0.9;
	dy <- 0.025;
	text(-0.5,-0.4-dy,"Partial speciation [1]", col=colspe, cex=tcex, adj=0)
	text(-0.5,-0.45-dy,"Full speciation [0]", col=coltot, cex=tcex, adj=0)
	text(-0.5, -0.35-dy, "No speciation", col=colno, cex=tcex, adj=0)
	points(trans3d(1,0,0,p0)$x, trans3d(1,0,0,p0)$y, col='white', pch=16, cex=2)
	points(trans3d(1,0,1,p0)$x, trans3d(1,0,1,p0)$y, col='white', pch=16, cex=2)
	tcex=0.9;
	dy <- 0.025;
dev.off()

## PLOT THE LEGEND

pdf('figures/legfig3A.pdf', width=1.5, height=0.75)
	ccex <- 0.75	# Relative font size
	par(las=1, mar=c(0, 0, 0, 6)+0.2, cex.axis=ccex)

	# Dots
	plot(rep(1, 2), c(1, 2), axes=FALSE, ylab='', xlab='', ylim=c(0,2.25), pch=c(24, 21), bg=c(colspe, coltot), col=c(colspe, coltot))

	# Legend
	mtext('  Partial speciation [1]', 4, at=c(1), cex=ccex, col=gray(0.5))
	mtext('  Full speciation [0]', 4, at=c(2), cex=ccex, col=gray(0))
dev.off()


