# data: Thibert-Plante and Hendry, 2011, JEB 24(10):2186--2196.   #

# Clear the memory
rm(list=ls())
# Close all figure windows
for(i in dev.list())dev.off()

## LOAD THE DATA
# Note: won't work if you do not have TPH's data file
cat('Loading the data...')
source('fig3A.R')
cat('done\n')

# COMBINE THE X AND Y AXES INTO Chi
xytogether <- function(tab){
	out <- tab$dPos^2 - 4*abs(tab$sR^2 - tab$sC^2); 
}
XY0 <- xytogether(x)
sXY0 <- 1*(XY0>0)

## ANALYZE - AGGREGATE
# Compute selection index (disruptive or not)
sel <- (1/4*x$dPos^2 + (x$sR^2 - x$sC^2)) #(2*x$sC - sqrt(x$dPos^2 + 4*x$sR^2))

# Gather all data
nx.all <- as.data.frame(cbind(tot=totsymspe, symspe=symspe, pref=prefs, bimod=CC, sel=sel, XY=XY0))
anx.all <- aggregate(nx.all, by=list(nx.all$pref, nx.all$XY), mean)
anx.all.len <- aggregate(nx.all, by=list(nx.all$pref, nx.all$XY), length)

# Mating Preferences
tprefs <- anx.all$pref; 
x0 <- 0.06;
tprefs[tprefs==0] <- x0 # Change zeros into a small value, because log scale
anx.all$pref <- tprefs

## PLOTTING

pdf('figures/fig3B.pdf', width=3.5, height=3.5)

	par(las=1, mar=c(4, 4, 0,0)+0.2)
	colbg <- gray(0.925);	# Color of the rectangle

	# Plotting parameters
	thecex <- 1
	thecoldot <- gray(0.4)
	pchdot <- '.'
	thelwd <- 0.5
	lwddot <- 1
	lg <- 'y'

	# Plot ranges
	ym <- 0.05
	yM <- 50
	xm <- -0.5
	xM <- 1.05*max(anx.all[,2])

	# Plot parameter combinations
	plot(anx.all[,2], anx.all$pref, log=lg, bg='white', pch=pchdot, col=thecoldot, cex=thecex, xlim=c(xm,xM), ylim=c(ym,yM), axes=FALSE, xlab='', ylab='Strength of assortment (Z)', lwd=lwddot)
	mtext(bquote(paste('Selection and resources (', chi, ')', sep="")), 1, 2)

	# Plot the rectangle for assortment (gray when random)
	tym <- ym;
	tyM <- 1.2*x0;
	txm <- xm;
	txM <- xM;
	polygon(c(txm,txM,txM,txm,txm), c(tym,tym,tyM,tyM,tym), col=colbg, border=colbg)

	# Plot the rectangle for XY (gray when chi<0)
	ttym <- ym;
	ttyM <- yM;
	ttxm <- xm;
	ttxM <- 0;
	polygon(c(ttxm,ttxM,ttxM,ttxm,ttxm), c(ttym,ttym,ttyM,ttyM,ttym), col=colbg, border=colbg)

	# Re-plot the parameter combinations
	points(anx.all[,2], anx.all$pref, bg=rgb(1,1,1,0), pch=pchdot, col=thecoldot, cex=thecex, xlim=c(xm,xM), ylim=c(ym,yM), lwd=lwddot)

	# Add axes
	axis(1, pos=ym)
	axis(2, pos=xm, at=c(x0,0.25,1,10, 50), labels=c('Random','0.25','1.0','10','50'))

	# Add lines for Random and Chi=0
	lines(c(txm, txM), rep(tyM, 2))
	lines(rep(ttxM, 2), c(ttym, ttyM))

	
	isym <- itot <- 1:length(anx.all$pref)

	# Color codes
	xxspe <- 0.7
	colspe <- gray(xxspe);		# On their way (0<hybrid3<maxhybrid)
	coltot <- gray(0);	# Total sympatric speciation (hybrid3==0)

	# Color vectors, opacity proportional to frequency
	thecolspe <- rgb(xxspe,xxspe, xxspe, anx.all$symspe)
	thecoltot <- rgb(0,0,0, anx.all$tot)

	points(anx.all[,2], anx.all$pref, bg=thecolspe, pch=24, col=rgb(1,1,1,0), cex=thecex, lwd=thelwd)
	points(anx.all[,2], anx.all$pref, bg=thecoltot, pch=21, col=rgb(1,1,1,0), cex=thecex, lwd=thelwd)

dev.off()


## PLOT THE LEGEND
pdf('figures/legfig3B.pdf', width=3, height=1.)
	ccex <- 0.75	# Relative font size
	par(las=1, mar=c(1.75, 0, 0.75, 6)+0.2, cex.axis=ccex)

	# List of positions of the dots
	xlist <- seq(0,1,by=0.1)
	nx <- length(xlist)

	# Plot small dots
	plot(rep(xlist, 2), c(rep(1, nx), rep(2, nx)), axes=FALSE, ylab='', xlab='', ylim=c(0,2.25), pch=pchdot, col=thecoldot)
	# Add dots for [1]
	points(xlist, rep(1, nx), pch=24, col=rgb(1,1,1,0), bg=rgb(xxspe, xxspe, xxspe, xlist))
	# Add dots for [0]
	points(xlist, rep(2, nx), pch=21, col=rgb(1,1,1,0), bg=rgb(0,0,0, xlist))

	# Axis
	posx <- 0.5
	axis(1, at=c(0, 0.5, 1), labels=c('', '', ''), pos=posx)
	axis(1, at=c(0.25, 0.75), labels=c('', ''), pos=posx, tck=-0.1, lwd=0, lwd.ticks=1)

	mtext(c('0','0.5','1'), 1, 0., at=c(0,0.5,1), cex=ccex)
	mtext('Frequency', 1, 0.75, cex=ccex)

	# Legend
	mtext('  Partial speciation [1]', 4, at=c(1), cex=ccex, col=gray(0.5))
	mtext('  Full speciation [0]', 4, at=c(2), cex=ccex, col=gray(0))
dev.off()

