# Clear the memory
rm(list=ls())
# Close all figure windows
for(i in dev.list())dev.off()

## PARAMETERS WHICH CAN BE CHANGED
# Here I take the values present in the 2011 JEB paper
#  but changing these values change the pies charts (it's worth playing with them..,)

# Minimum value of "adapt" to declare the pop adapted (= remove zone 3)
adaptthr <- 0.7;

# Maximum value of "hybrids3" to declare incipient sympatric speciation ( = limit between zones 1 and 2)
#		Max stringency = 0
#		Min stringency = 1
maxhybrid <- 0.6;
# There is another point at 0 anyway, for the limit between zones 0 and 1

## GRAPHICAL PARAMETERS
thepch <- 20;	# Type of point for total speciation
ylb <- 'Frq. sympatric speciation'	# Y label
coltot <- gray(0);	# Total sympatric speciation (hybrid3==0)

## LOAD DATA
# Load and format
# [Xavier's code]
load("data/rep09.RData")
y<-matrix(NA,ncol=length(x[1,]),nrow=length(x[,1]))
for (i in 1:length(x[1,])) {
   y[,i]<-as.numeric(x[,i])
}
tmpColname<-colnames(x)
tmpColname[32]<-"meanPref"
colnames(y)<-tmpColname
x<-y
x<-data.frame(x)
rm(y)
# [end of Xavier's code]

# Remove data:
# Remove data where there are NAs
x <- x[!is.na(x$myVar),]

adapt<-x$popS/x$K
# Optional: remove data where adaptation is below a threshold (for instance 0.7 to remove zone 3)
ia <- adapt>adaptthr;
x <- x[ia,];# Remove the case where c<1/2 (because weird function, does not correspond to disassortative mating, and c=0)
x <- x[x$maxPref!=0.3 & x$maxPref!=0,];
# Remove sC and sR = 1000, because correspond to virtually no selection
y <- x[x$sC!=1000 & x$sR!=1000,];
iweak <- 1*((x$sC!=1000) & (x$sR!=1000));

## ANALYZE DATA
# CRITERION FOR SYMPATRIC SPECIATION
# Mode of the distribution
# [Xavier's code]
bino<-rep(0,17)
for (i in 1:17){
k<-i-1
bino[i]<-(factorial(17)/(factorial(k)*factorial(17-k)) )* (0.5)^17
}
hybrids1<-((x$center1/x$popS)/sum(bino[8+1]))
hybrids2<-((x$center2/x$popS)/sum(bino[(7:9)+1]))
hybrids3<-((x$center3/x$popS)/sum(bino[(6:10)+1]))
# [end of Xavier's code]
# NOTE: This is a corrected version. The midpoint between 1 and 17 is not 8, but it is 9. 

# COMPUTE THE THREE COMPOUND PARAMETERS
# Dimension 1 (CC): whether the distribution of resources is bimodal
# This is the second derivative of the distribution of resources at (Delta theta)/2
# !!! THIS IS THE ABSOLUTE MODALITY OF THE RESOURCES !!!
# sCC = 1 when bimodal
concav <- function(tab){
	out <- tab$dPos^2 - 4*tab$sR^2; 
}
CC <- concav(x)
sCC <- 1*(CC>0)

# Dimension 2 (SS): whether selection is globally stabilizing
# This is the condition for disruptive selection, derived under an Adaptive Dynamics framework
# (the derivation is not trival, the result looks simple...)
# sSS = 1 when disruptive
stabsel <- function(tab, thr=0){
	cb <- ((2*tab$sC - sqrt(tab$dPos^2 + 4*tab$sR^2))>thr)+1;
}
SS <- stabsel(x)
sSS <- 1*(SS==1)

# Dimension 3 (PP): strengh of preference
# sPP = 0 for random mating, = 1 when some assortment
prefs <- (2*x$maxPref-1)^2/(2*x$sA^2)
sPP <- 0*(prefs==0) + 1*(prefs>0)

# Index of whether sympatric speciation
# You can change the threshold (see above)
symspe <- 1*(hybrids3<=maxhybrid)	# Incipient sympatric speciation ("zone 1")
totsymspe <- 1*(hybrids3==0)			# Full sympatric speciation ("zone 0")
sel <- (2*x$sC - sqrt(x$dPos^2 + 4*x$sR^2))

CC3 <- 0*(CC<(-100))-1*(CC<0)+1*(CC>=0)

# AGGREGATE RESULTS
# With all data
nx.all <- as.data.frame(cbind(tot=totsymspe, symspe=symspe, pref=prefs, bimod=CC3, sel=sel))
anx.all <- aggregate(nx.all, by=list(nx.all$bimod), mean)
anx.all.nb <- aggregate(nx.all, by=list(nx.all$bimod), sum)

# Remove no-selection data points
ny.all <- as.data.frame(cbind(tot=totsymspe[iweak==1], symspe=symspe[iweak==1], pref=prefs[iweak==1], bimod=CC3[iweak==1], sel=sel[iweak==1]))
any.all <- aggregate(ny.all, by=list(ny.all$bimod), mean)
any.all.nb <- aggregate(ny.all, by=list(ny.all$bimod), sum)

## PLOTTING
# Some parameters
yl <- range(c(anx.all$tot, any.all$tot))
pchh <- thepch;

pdf('figures/figS2.pdf', width=5.5, height=5)
	par(mar=c(3,4.2,0,2)+0.2, cex=2, las=1)

	# All data points
	plot(1:2, anx.all$tot, type='p', lwd=20, ylab="", xlab="", xlim=c(0.75,2.25),pch=pchh, ylim=c(0,round(yl[2],1)), frame=TRUE, axes=FALSE, col=gray(0.6)) 
	# Without no selection
	points(1:2, any.all$tot, type='p', lwd=20,pch=pchh, col=coltot, cex=0.3) 

	axis(1, at=1:2, labels=c("Unimodal", "Bimodal"), padj=1)
	axis(2, at=seq(0,0.1,by=0.025))
	mtext(ylb, 2, line=3.35, cex=2, las=0)
dev.off()
