# data: Thibert-Plante and Hendry, 2011, JEB 24(10):2186--2196.   #

# Clear the memory
rm(list=ls())
# Close all figure windows
for(i in dev.list())dev.off()

## LOAD THE DATA
# Note: won't work if you do not have TPH's data file
cat('Loading the data...')
source('fig3A.R')
cat('done\n')

## ANALYZE - AGGREGATE
# Compute selection index (disruptive or not)
sel <- (1/4*x$dPos^2 + (x$sR^2 - x$sC^2)) #(2*x$sC - sqrt(x$dPos^2 + 4*x$sR^2))

# Gather all data
nx.all <- as.data.frame(cbind(tot=totsymspe, symspe=symspe, pref=prefs, bimod=CC, sel=sel))
anx.all <- aggregate(nx.all, by=list(nx.all$pref, nx.all$bimod), mean)

# Aggregate it along each axis
# Assortment
anx.all.pref <- aggregate(nx.all, by=list(nx.all$pref), mean)
# Resource shape
anx.all.bimod <- aggregate(nx.all, by=list(nx.all$bimod), mean)
# Selection
anx.all.sel <- aggregate(nx.all, by=list(nx.all$sel), mean)

## PLOTTING
# (boring) Plotting parameters
daw <- 4.5;	# Width of the pdf
dah <- 3.5;	# Height of the pdf
damar <- c(4.5,4,0.8,0.25)+0.2	# Margins
dacex <- 1.3;	# Size of the points
damgp <- c(3, 1, 0);	# Position of the axis labels
thelas <- 1;	# Orientation of the yaxis labels
cexspe <- 0.7;	# Size of the points [1]
mcex <- 1.25;	# Size of mtext

yl <- c(0,1.0)	# Range of the plot
ytck <- seq(0,1,by=0.25);	# Ticks on the y axes
thepch <- 20;	# Type of point for total speciation
thepch2 <- 17; # and for partial

ytxt <- 0.95*yl[2];	# Position of the labels
ylb <- 'Frq. sympatric speciation'	# Y label
colbg <- gray(0.925);	# Color of the rectangle

# SELECTION AXIS
pdf('figures/data_selection.pdf', width=daw, height=dah)
	par(mar=damar, cex=dacex, las=thelas, mgp=damgp)
	# Initiate the plot
	plot(anx.all.sel$sel, anx.all.sel$symspe, ylab=ylb, xlab="Disruptiveness of selection (Y)", pch=thepch2, ylim=yl, frame.plot=FALSE, axes=FALSE, col='white')
	# Plot the rectangle
	txm <- min(anx.all.sel$sel);
	txM <- 0;
	tym <- yl[1];
	tyM <- yl[2];
	polygon(c(txm,txM,txM,txm,txm), c(tym,tym,tyM,tyM,tym), col=colbg, border=colbg)
	# Plot the data
	points(anx.all.sel$sel, anx.all.sel$symspe, pch=thepch2, col=colspe, cex=cexspe)
	points(anx.all.sel$sel, anx.all.sel$tot, pch=thepch, col=coltot)
	axis(1, pos=0)
	axis(2, at=ytck, pos=min(anx.all.sel$sel), outer=TRUE)
	lines(c(0,0), c(0,1))
	mtext(at=c(-0.05),'Stabilizing', side=3, cex=mcex)
	mtext(at=c(0.2),'Disruptive', side=3, cex=mcex)
dev.off()

# MATING AXIS
pdf('figures/data_mating.pdf', width=daw, height=dah)
	par(mar=damar, cex=dacex, las=thelas, mgp=damgp)
	x0 <- 0.06;
	tprefs <- anx.all.pref$pref; tprefs[tprefs==0] <- x0
	plot(tprefs, anx.all.pref$symspe, ylab=ylb, xlab="Strength of assortment (Z)",log='x', pch=thepch2, ylim=yl, frame=FALSE, axes=FALSE, col='white', xlim=c(x0,100))
	txm <- 0.8*x0;
	txM <- 1.2*x0;
	tym <- yl[1];
	tyM <- yl[2];
	polygon(c(txm,txM,txM,txm,txm), c(tym,tym,tyM,tyM,tym), col=colbg, border=colbg)
	points(tprefs, anx.all.pref$symspe, pch=thepch2, col=colspe, cex=cexspe)
	points(tprefs, anx.all.pref$tot, pch=thepch, col=coltot)
	axis(1, at=c(x0,0.25,1,10, 50), labels=c('0','0.25','1.0','10','50'), pos=0)
	axis(2, at=ytck, pos=min(txm))
	lines(c(txM,txM), c(0,1))
	arrows(x0, 1.1*yl[2], x0, 0.95*yl[2], length=0.05)
	lines(c(0,0), c(0,1))
	mtext(at=c(x0),text='Random', side=3, cex=mcex)
	mtext(at=c(1),text='Assortative', side=3, cex=mcex)
dev.off()

# RESOURCES AXIS
pdf('figures/data_resources.pdf', width=daw, height=dah)
	par(mar=damar, cex=dacex, las=thelas, mgp=damgp)
	plot(anx.all.bimod$bimod, anx.all.bimod$symspe, ylab=ylb, xlab="Resources (X)", pch=thepch2, ylim=yl, frame=FALSE, axes=FALSE, col='white') 
	txm <- -0.5;
	txM <- 0;
	tym <- yl[1];
	tyM <- yl[2];
	polygon(c(txm,txM,txM,txm,txm), c(tym,tym,tyM,tyM,tym), col=colbg, border=colbg)
	points(anx.all.bimod$bimod, anx.all.bimod$symspe, pch=thepch2, col=colspe, cex=cexspe) 
	points(anx.all.bimod$bimod, anx.all.bimod$tot, pch=thepch, col=coltot)
	axis(1, pos=0, at=c(-0.5,0,0.5,1,1.5))
	axis(2, at=ytck, pos=-0.5)
	lines(c(0,0), c(0,1))
	mtext(at=c(-0.25),text='Unimodal', side=3, cex=mcex)
	mtext(at=c(0.6),text='Bimodal', side=3, cex=mcex)
dev.off()

## PLOTTING THE CUBES
# Function for the cube's grid
plotgrid <- function(){
	lines3d(x=c(0,1,1,0,0), y=c(0,0,1,1,0), z=rep(0,5), col=gridcol)
	lines3d(x=c(0,1,1,0,0), y=c(0,0,1,1,0), z=rep(1,5), col=gridcol)
	lines3d(x=rep(0,2), z=c(0,1), y=rep(0,2), col=gridcol)
	lines3d(x=rep(1,2), z=c(0,1), y=rep(0,2), col=gridcol)
	lines3d(x=rep(0,2), z=c(0,1), y=rep(1,2), col=gridcol)
	lines3d(x=rep(1,2), z=c(0,1), y=rep(1,2), col=gridcol)
}

alim <- c(0,1);	# Plot range
marp <- rep(0,4);	# Margins

colrec <- gray(0.2);	# Cube color
cuw <- 3;	# Size of the pdf window
cuh <- cuw;

xfaces <- c(rep(c(0,1,1,0,0),4), rep(0,5), rep(1,5));
yfaces <- c(rep(c(0,0,1,1,0),2),rep(0,5),rep(1,5), rep(c(0,1,1,0,0),2));
zfaces <- c(rep(0.,5),rep(1,5),rep(c(0,0,1,1,0), 2), rep(c(0,0,1,1,0),2));

xwall <- c(0,0,1,1,0);
ywall <- rep(1,5);
zwall <- c(0,1,1,0,0);

pdf('figures/cube_mating.pdf', width=cuw, height=cuh)
	par('mar'=marp)
	# Initiate the plot
	p0 <- plot3d(x=xagg$sCC, y=xagg$sSS, z=xagg$sPP, col='white', axes=FALSE, box=FALSE, mar=marp, xlab="",ylab="",zlab="", xlim=alim, zlim=alim, ylim=alim, theta=30, phi=20, r=2, d=1)
	polygon3d(x=xfaces, y=yfaces, z=0.5*zfaces, col=colbg, border=colbg)
	polygon3d(x=zwall, y=xwall, z=0.5*ywall, col=colbg, border=gridcol)
	# Plot the cube
	plotgrid()
dev.off()

pdf('figures/cube_resources.pdf', width=cuw, height=cuh)
	par('mar'=marp)
	# Initiate the plot
	p0 <- plot3d(x=xagg$sCC, y=xagg$sSS, z=xagg$sPP, col='white', axes=FALSE, box=FALSE, mar=marp, xlab="",ylab="",zlab="", xlim=alim, zlim=alim, ylim=alim, theta=30, phi=20, r=2, d=1)
	polygon3d(x=0.5*xfaces, y=yfaces, z=zfaces, col=colbg, border=colbg)
	polygon3d(x=0.5*ywall, y=zwall, z=xwall, col=colbg, border=gridcol)
	# Plot the cube
	plotgrid()
dev.off()

pdf('figures/cube_selection.pdf', width=cuw, height=cuh)
	par('mar'=marp)
	# Initiate the plot
	p0 <- plot3d(x=xagg$sCC, y=xagg$sSS, z=xagg$sPP, col='white', axes=FALSE, box=FALSE, mar=marp, xlab="",ylab="",zlab="", xlim=alim, zlim=alim, ylim=alim, theta=30, phi=20, r=2, d=1)
	polygon3d(x=xfaces, y=0.5*yfaces, z=zfaces, col=colbg, border=colbg)
	polygon3d(x=xwall, y=0.5*ywall, z=zwall, col=colbg, border=gridcol)
	# Plot the cube
	plotgrid()
dev.off()
